@@ -120,9 +120,11 @@ void ScriptRepositoryDialog::searchScript(int page) {
     QNetworkRequest networkRequest(url);
     _page = page;
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
     networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
                                 true);
+#else
+    networkRequest.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
 #endif
 
 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
@@ -152,9 +154,11 @@ void ScriptRepositoryDialog::searchForUpdates() {
         QUrl url = script.repositoryInfoJsonUrl();
         QNetworkRequest networkRequest(url);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
         networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
                                     true);
+#else
+        networkRequest.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
 #endif
 
 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
@@ -242,9 +246,11 @@ void ScriptRepositoryDialog::parseCodeSearchReply(const QByteArray &arr) {
         QUrl url(_rawContentUrlPrefix + path);
         QNetworkRequest networkRequest(url);
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
         networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
                                     true);
+#else
+        networkRequest.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
 #endif
 
 #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
@@ -444,7 +450,7 @@ QJsonObject ScriptRepositoryDialog::getCurrentInfoJsonObject() {
 QString ScriptRepositoryDialog::getCurrentInfoJsonString() {
     QTreeWidgetItem *item = ui->scriptTreeWidget->currentItem();
 
-    if (item == Q_NULLPTR) {
+    if (item == nullptr) {
         return QString();
     }
 
