@@ -172,7 +172,7 @@ class MarkdownHighlighter : public QSyntaxHighlighter {
         CodeCMake = 242,
         CodeMake = 244
     };
-    Q_ENUMS(HighlighterState)
+    Q_ENUM(HighlighterState)
 
     static void setTextFormats(
         QHash<HighlighterState, QTextCharFormat> formats);
@@ -210,7 +210,7 @@ class MarkdownHighlighter : public QSyntaxHighlighter {
     };
 
 
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
+    void highlightBlock(const QString &text) override;
 
     static void initTextFormats(int defaultFontSize = 12);
 
