@@ -20,7 +20,6 @@
 #include <QDir>
 #include <QGuiApplication>
 #include <QKeyEvent>
-#include <QWheelEvent>
 #include <QLayout>
 #include <QPainter>
 #include <QPainterPath>
@@ -31,10 +30,11 @@
 #include <QSettings>
 #include <QTextBlock>
 #include <QTimer>
+#include <QWheelEvent>
 #include <utility>
 
-#include "markdownhighlighter.h"
 #include "linenumberarea.h"
+#include "markdownhighlighter.h"
 
 static const QByteArray _openingCharacters = QByteArrayLiteral("([{<*\"'_~");
 static const QByteArray _closingCharacters = QByteArrayLiteral(")]}>*\"'_~");
@@ -49,11 +49,10 @@ QMarkdownTextEdit::QMarkdownTextEdit(QWidget *parent, bool initHighlighter)
     updateLineNumberAreaWidth(0);
 
     // markdown highlighting is enabled by default
-    _highlightingEnabled = true;
+    _highlightingEnabled = initHighlighter;
     if (initHighlighter) {
         _highlighter = new MarkdownHighlighter(document());
     }
-    //    setHighlightingEnabled(true);
 
     QFont font = this->font();
 
@@ -106,7 +105,7 @@ QMarkdownTextEdit::QMarkdownTextEdit(QWidget *parent, bool initHighlighter)
     updateSettings();
 
     // workaround for disabled signals up initialization
-    QTimer::singleShot(300, this, SLOT(adjustRightMargin()));
+    QTimer::singleShot(300, this, &QMarkdownTextEdit::adjustRightMargin);
 }
 
 void QMarkdownTextEdit::setLineNumbersCurrentLineColor(QColor color) {
@@ -341,7 +340,7 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
                     setTextCursor(cursor);
                 }
             }
-            return false;
+            return QPlainTextEdit::eventFilter(obj, event);
         } else if ((keyEvent->key() == Qt::Key_Up) &&
                    keyEvent->modifiers().testFlag(Qt::NoModifier)) {
             // if you are in the first line and press cursor up the cursor will
@@ -359,7 +358,7 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
                     setTextCursor(cursor);
                 }
             }
-            return false;
+            return QPlainTextEdit::eventFilter(obj, event);
         } else if (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) {
             return handleReturnEntered();
         } else if ((keyEvent->key() == Qt::Key_F3)) {
@@ -383,7 +382,7 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
             return true;
         }
 
-        return false;
+        return QPlainTextEdit::eventFilter(obj, event);
     } else if (event->type() == QEvent::KeyRelease) {
         auto *keyEvent = static_cast<QKeyEvent *>(event);
 
@@ -392,7 +391,7 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
             resetMouseCursor();
         }
 
-        return false;
+        return QPlainTextEdit::eventFilter(obj, event);
     } else if (event->type() == QEvent::MouseButtonRelease) {
         _mouseButtonDown = false;
         auto *mouseEvent = static_cast<QMouseEvent *>(event);
@@ -416,9 +415,9 @@ bool QMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
         // emit zoom signals
         if (wheel->modifiers() == Qt::ControlModifier) {
             if (wheel->angleDelta().y() > 0) {
-                emit zoomIn();
+                Q_EMIT zoomIn();
             } else {
-                emit zoomOut();
+                Q_EMIT zoomOut();
             }
 
             return true;
@@ -877,8 +876,9 @@ bool QMarkdownTextEdit::handleBackspaceEntered() {
     const int positionInBlock = cursor.positionInBlock();
     int block = cursor.block().blockNumber();
 
-    if (_highlighter->isPosInACodeSpan(block, positionInBlock - 1))
-        return false;
+    if (_highlighter)
+        if (_highlighter->isPosInACodeSpan(block, positionInBlock - 1))
+            return false;
 
     // return if backspace was pressed at the beginning of a block
     if (positionInBlock == 0) {
@@ -920,7 +920,7 @@ bool QMarkdownTextEdit::handleBackspaceEntered() {
         if (pos == 5 || pos == 6)
             isCloser = isQuotCloser(positionInBlock - 1, text);
         else
-            isCloser = pos == -1 ? false : true;
+            isCloser = pos != -1;
         if (isCloser)
             charToRemove = _openingCharacters.at(pos);
         else
@@ -967,6 +967,9 @@ bool QMarkdownTextEdit::handleBackspaceEntered() {
 bool QMarkdownTextEdit::handleCharRemoval(MarkdownHighlighter::RangeType type,
                                           int block, int position)
 {
+    if (!_highlighter)
+        return false;
+
     auto range = _highlighter->findPositionInRanges(type, block, position);
     if (range == QPair<int, int>{-1, -1})
         return false;
@@ -1039,7 +1042,7 @@ bool QMarkdownTextEdit::increaseSelectedTextIndention(
             //          QSettings settings;
             const int indentSize = indentCharacters == QStringLiteral("\t")
                                        ? 4
-                                       : indentCharacters.count();
+                                       : indentCharacters.length();
 
             // remove leading \t or spaces in following lines
             newText = selectedText.replace(
@@ -1078,7 +1081,7 @@ bool QMarkdownTextEdit::increaseSelectedTextIndention(
 
         return true;
     } else if (reverse) {
-        const int indentSize = indentCharacters.count();
+        const int indentSize = indentCharacters.length();
 
         // do the check as often as we have characters to un-indent
         for (int i = 1; i <= indentSize; i++) {
@@ -1149,7 +1152,7 @@ bool QMarkdownTextEdit::openLinkAtCursorPosition() {
 
     qDebug() << __func__ << " - 'emit urlClicked( urlString )': " << urlString;
 
-    emit urlClicked(urlString);
+    Q_EMIT urlClicked(urlString);
 
     if ((url.isValid() && isValidUrl(urlString)) || isRelativeFileUrl ||
         isLegacyAttachmentUrl) {
@@ -1377,7 +1380,8 @@ void QMarkdownTextEdit::setText(const QString &text) { setPlainText(text); }
 void QMarkdownTextEdit::setPlainText(const QString &text) {
     // clear the dirty blocks vector to increase performance and prevent
     // a possible crash in QSyntaxHighlighter::rehighlightBlock
-    _highlighter->clearDirtyBlocks();
+    if (_highlighter)
+        _highlighter->clearDirtyBlocks();
 
     QPlainTextEdit::setPlainText(text);
     adjustRightMargin();
@@ -1615,7 +1619,7 @@ void QMarkdownTextEdit::setAutoTextOptions(AutoTextOptions options) {
     _autoTextOptions = options;
 }
 
-void QMarkdownTextEdit::updateLineNumberArea(const QRect &rect, int dy)
+void QMarkdownTextEdit::updateLineNumberArea(const QRect rect, int dy)
 {
     if (dy)
         _lineNumArea->scroll(0, dy);
