@@ -359,6 +359,14 @@ bool DatabaseService::setupNoteFolderTables() {
         version = 14;
     }
 
+    if (version < 15) {
+        // https://github.com/pbek/QOwnNotes/issues/2292
+        queryDisk.exec(QStringLiteral(
+            "ALTER TABLE noteTagLink ADD stale_date DATETIME DEFAULT NULL"));
+
+        version = 15;
+    }
+
     if (version != oldVersion) {
         setAppData(QStringLiteral("database_version"), QString::number(version),
                    QStringLiteral("note_folder"));
@@ -874,6 +882,41 @@ bool DatabaseService::setupTables() {
         version = 37;
     }
 
+    // version 38 was spent
+
+    if (version < 39) {
+        // migrate from customNoteFileExtensionList to noteFileExtensionList
+        auto extensions = settings.value(
+              QStringLiteral("customNoteFileExtensionList")).toStringList();
+
+        settings.setValue(
+            QStringLiteral("noteFileExtensionList"),
+            extensions);
+        settings.remove(QStringLiteral("customNoteFileExtensionList"));
+
+        version = 39;
+    }
+
+    if (version < 40) {
+        const auto bookmarksNoteName = settings.value(
+          QStringLiteral("webSocketServerService/bookmarksNoteName")).toString();
+
+        // fix overwritten bookmarksNoteName
+        if (bookmarksNoteName == QStringLiteral("Commands")) {
+            settings.setValue(
+                QStringLiteral("webSocketServerService/bookmarksNoteName"),
+                QStringLiteral("Bookmarks"));
+        }
+
+        version = 40;
+    }
+
+    if (version < 41) {
+        queryDisk.exec(QStringLiteral(
+            "ALTER TABLE cloudConnection ADD account_id VARCHAR(255)"));
+        version = 41;
+    }
+
     if (version != oldVersion) {
         setAppData(QStringLiteral("database_version"),
                    QString::number(version));
