@@ -28,6 +28,8 @@ QOwnNotesMarkdownTextEdit::QOwnNotesMarkdownTextEdit(QWidget *parent)
     : QMarkdownTextEdit(parent, false) {
     mainWindow = nullptr;
 
+    // We need to set the internal variable to true, because we start with a highlighter
+    _highlightingEnabled = true;
     _highlighter = nullptr;
     if (parent->objectName() != QStringLiteral("LogWidget")) {
         _highlighter = new QOwnNotesMarkdownHighlighter(document());
@@ -110,7 +112,9 @@ void QOwnNotesMarkdownTextEdit::setFormatStyle(
     MarkdownHighlighter::HighlighterState index) {
     QTextCharFormat format;
     Utils::Schema::schemaSettings->setFormatStyle(index, format);
-    _highlighter->setTextFormat(index, format);
+    if (_highlighter) {
+        _highlighter->setTextFormat(index, format);
+    }
 }
 
 /**
@@ -304,7 +308,9 @@ int QOwnNotesMarkdownTextEdit::modifyFontSize(FontModificationMode mode) {
 
     if (doSetStyles) {
         this->setStyles();
-        _highlighter->rehighlight();
+        if (_highlighter) {
+            _highlighter->rehighlight();
+        }
     }
 
     return fontSize;
@@ -885,7 +891,9 @@ void QOwnNotesMarkdownTextEdit::updateSettings() {
         if (highlightingEnabled) {
             // set the new highlighting styles
             setStyles();
-            _highlighter->rehighlight();
+            if (_highlighter) {
+                _highlighter->rehighlight();
+            }
         }
     }
 
@@ -977,7 +985,10 @@ void QOwnNotesMarkdownTextEdit::onContextMenu(QPoint pos) {
     printTextAction->setEnabled(isTextSelected);
     printTextAction->setIcon(printIcon);
     connect(printTextAction, &QAction::triggered, this, [this](){
-        mainWindow->printTextDocument(document());
+        // print the selected text
+        auto *textEdit = new QOwnNotesMarkdownTextEdit(this);
+        textEdit->setPlainText(mainWindow->selectedNoteTextEditText());
+        mainWindow->printTextDocument(textEdit->document());
     });
 
     // add the print selected text (preview) action
@@ -986,14 +997,15 @@ void QOwnNotesMarkdownTextEdit::onContextMenu(QPoint pos) {
     printHTMLAction->setEnabled(isTextSelected);
     printHTMLAction->setIcon(printIcon);
     connect(printHTMLAction, &QAction::triggered, this, [this](){
+        // print the selected text (preview)
         auto note = mainWindow->getCurrentNote();
         QString html = note.textToMarkdownHtml(
-            toPlainText(), NoteFolder::currentLocalPath(),
+            mainWindow->selectedNoteTextEditText(), NoteFolder::currentLocalPath(),
             mainWindow->getMaxImageWidth(),
             Utils::Misc::useInternalExportStylingForPreview());
-        QTextDocument doc;
-        doc.setHtml(html);
-        mainWindow->printTextDocument(&doc);
+        auto *textEdit = new QTextEdit(this);
+        textEdit->setHtml(html);
+        mainWindow->printTextDocument(textEdit->document());
     });
 
     // add the export menu
@@ -1014,7 +1026,10 @@ void QOwnNotesMarkdownTextEdit::onContextMenu(QPoint pos) {
     exportTextAction->setEnabled(isTextSelected);
     exportTextAction->setIcon(pdfIcon);
     connect(exportTextAction, &QAction::triggered, this, [this](){
-        mainWindow->exportNoteAsPDF(document());
+        // export the selected text as PDF
+        auto *textEdit = new QOwnNotesMarkdownTextEdit(this);
+        textEdit->setPlainText(mainWindow->selectedNoteTextEditText());
+        mainWindow->exportNoteAsPDF(textEdit->document());
     });
 
     // add the export selected text (preview) action
@@ -1026,7 +1041,7 @@ void QOwnNotesMarkdownTextEdit::onContextMenu(QPoint pos) {
         // export the selected text (preview) as PDF
         auto note = mainWindow->getCurrentNote();
         QString html = note.textToMarkdownHtml(
-            toPlainText(), NoteFolder::currentLocalPath(),
+            mainWindow->selectedNoteTextEditText(), NoteFolder::currentLocalPath(),
             mainWindow->getMaxImageWidth(),
             Utils::Misc::useInternalExportStylingForPreview());
         html = Utils::Misc::parseTaskList(html, false);
@@ -1208,10 +1223,10 @@ bool QOwnNotesMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
                         if (mainWindow != nullptr) {
                             mainWindow->allowNoteEditing();
                         }
-                        // If the answer is overriden to Yes ("Don't ask again" with "Yes"),
+                        // If the answer is overridden to Yes ("Don't ask again" with "Yes"),
                         // what you type then only enables note editing, but is not typed in
                         // the editor. We need to re-send the event after enabling editing.
-                        // BUT, we should do that only if the msgbox is overriden to Yes,
+                        // BUT, we should do that only if the msgbox is overridden to Yes,
                         // not if manually answered.
                         // You may see: https://github.com/pbek/QOwnNotes/issues/2421
                         // This check is partially copied from utils/gui.cpp showMessage()
@@ -1220,7 +1235,7 @@ bool QOwnNotesMarkdownTextEdit::eventFilter(QObject *obj, QEvent *event) {
                         auto overrideButton = static_cast<QMessageBox::StandardButton>(
                             settings.value(settingsKey, QMessageBox::NoButton).toInt());
                         if (overrideButton == QMessageBox::Yes) {
-                            // overriden to answer yes: re-send the event
+                            // overridden to answer yes: re-send the event
                             return QMarkdownTextEdit::eventFilter(obj, event);
                         }
                     }
