@@ -1,15 +1,17 @@
 #include "scriptsettingwidget.h"
-#include <limits>
-#include "ui_scriptsettingwidget.h"
-#include <QDebug>
-#include <QJsonObject>
-#include <QJsonDocument>
+
 #include <dialogs/filedialog.h>
 
+#include <QDebug>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <limits>
+
+#include "ui_scriptsettingwidget.h"
+
 ScriptSettingWidget::ScriptSettingWidget(QWidget *parent, Script script,
-                                         QMap<QString, QVariant> variableMap) :
-    QWidget(parent),
-    ui(new Ui::ScriptSettingWidget) {
+                                         QMap<QString, QVariant> variableMap)
+    : QWidget(parent), ui(new Ui::ScriptSettingWidget) {
     ui->setupUi(this);
 
     _variableMap = variableMap;
@@ -34,6 +36,7 @@ ScriptSettingWidget::ScriptSettingWidget(QWidget *parent, Script script,
     ui->filePathButton->hide();
     ui->filePathLineEdit->hide();
     ui->booleanCheckBox->hide();
+    ui->selectionComboBox->hide();
 
     QJsonObject jsonObject = script.getSettingsVariablesJsonObject();
 
@@ -55,8 +58,8 @@ ScriptSettingWidget::ScriptSettingWidget(QWidget *parent, Script script,
 
         if (text.isEmpty()) {
             // fallback if no text was set
-            ui->booleanCheckBox->setText(description.isEmpty() ?
-                                         name : description);
+            ui->booleanCheckBox->setText(description.isEmpty() ? name
+                                                               : description);
             ui->descriptionLabel->hide();
         } else {
             ui->booleanCheckBox->setText(text);
@@ -92,19 +95,44 @@ ScriptSettingWidget::ScriptSettingWidget(QWidget *parent, Script script,
         ui->filePathLineEdit->setText(value);
         ui->filePathButton->show();
         ui->filePathLineEdit->show();
+    } else if (type == "selection") {
+        QMap<QString, QVariant> items = variableMap["items"].toMap();
+        QString value = jsonObject.value(identifier).toString();
+
+        if (jsonObject.value(identifier).isUndefined()) {
+            value = variableMap["default"].toString();
+        }
+
+        ui->selectionComboBox->clear();
+
+        QMapIterator<QString, QVariant> i(items);
+        int index = 0;
+        int currentIndex = 0;
+
+        while (i.hasNext()) {
+            i.next();
+            ui->selectionComboBox->addItem(i.value().toString(), i.key());
+
+            if (i.key() == value) {
+                currentIndex = index;
+            }
+
+            index++;
+        }
+
+        ui->selectionComboBox->setCurrentIndex(currentIndex);
+        ui->selectionComboBox->show();
     }
 }
 
-ScriptSettingWidget::~ScriptSettingWidget() {
-    delete ui;
-}
+ScriptSettingWidget::~ScriptSettingWidget() { delete ui; }
 
 /**
  * Stores a setting variable
  *
  * @param value
  */
-void ScriptSettingWidget::storeSettingsVariable(QJsonValue value) {
+void ScriptSettingWidget::storeSettingsVariable(const QJsonValue &value) {
     // we need to fetch the data again so we are not overwriting data of other
     // ScriptSettingWidget instances
     _script.refetch();
@@ -158,8 +186,8 @@ void ScriptSettingWidget::on_filePathButton_clicked() {
     QString identifier = _variableMap["identifier"].toString();
     QString description = _variableMap["description"].toString();
 
-    FileDialog dialog("ScriptSettingsFile-" + _script.getIdentifier() +
-                              "-" + identifier);
+    FileDialog dialog("ScriptSettingsFile-" + _script.getIdentifier() + "-" +
+                      identifier);
     dialog.setFileMode(QFileDialog::AnyFile);
     dialog.setAcceptMode(QFileDialog::AcceptOpen);
     dialog.setWindowTitle(tr("Please select a file"));
@@ -182,3 +210,8 @@ void ScriptSettingWidget::on_filePathButton_clicked() {
 void ScriptSettingWidget::on_booleanCheckBox_toggled(bool checked) {
     storeSettingsVariable(checked);
 }
+
+void ScriptSettingWidget::on_selectionComboBox_currentIndexChanged(int index) {
+    Q_UNUSED(index);
+    storeSettingsVariable(ui->selectionComboBox->currentData().toString());
+}
